# rpm-pack

[![Build Status](https://drone.libreschool.org/api/badges/libreschool-automation/rpm-pack/status.svg)](https://drone.libreschool.org/libreschool-automation/rpm-pack)

This docker image is used to build source .tar.gz for later package building.
You must have a .spec file from which the name, version and release are gathered.
All specified files are put in a new .tar.gz file, named "${name}-${version}.tar.gz".
Inside this archive, all specified files are put inside a directory called "${name}-${version}"


## Build

```
docker build . -t libreschool-automation/rpm-pack:latest
```

## How to use

```yml
kind: pipeline
name: default

steps:
  - name: create_targz
    image: git.libreschool.org/libreschool-automation/rpm-pack:latest
    pull: always
    settings:
      dest: myfile.tar.gz
      dir: myproject-1.0
      files:
        - root
        - createlinks.pl
        - README.md
        - COPYING
        - LICENSE
        - strange\,file.txt
```

Commas inside filenames should be escaped (or it'll be considered 2 distinct file names).

## Parameters

- `files` - files to be added to .tar.gz; defaults to `*`
- `dest` - destination archive; defaults to `${name}-${version}.tar.gz`
- `dir` - directory inside destination archive; defaults to `${name}-${version}`

Both `dest` and `dir` supports expansion of $NAME, $VERSION and $RELEASE. Like this:

```yml
kind: pipeline
name: default

steps:
  - name: create_targz
    image: git.libreschool.org/libreschool-automation/rpm-pack:latest
    pull: always
    settings:
      dest: $$NAME-$$VERSION-$$RELEASE.tar.gz
      dir: $$NAME-$$VERSION-$$RELEASE
      files:
        - root
        - createlinks.pl
        - README.md
        - COPYING
        - LICENSE
        - strange\,file.txt
```
